@@ -1,5 +1,5 @@
-"""Here is a small library for automatically adjustment of text position in matplotlib plots to minimize overlaps.
-This module is based on Phlya's repository: https://github.com/Phlya/adjustText
+"""Here is a small library for automatically adjustment of text position in matplotlib plots
+to minimize overlaps. This module is based on Phlya's repository: https://github.com/Phlya/adjustText
 <https://stackoverflow.com/questions/19073683/matplotlib-overlapping-annotations-text>
 
 Modify by Shujia Huang
@@ -17,8 +17,9 @@ import matplotlib
 def get_bboxes_pathcollection(sc, ax):
     """Function to return a list of bounding boxes in display coordinates
     for a scatter plot
-    Thank you to ImportanceOfBeingErnest
-    https://stackoverflow.com/a/55007838/1304161"""
+    Thank you to ImportanceOfBeingErnest:
+    https://stackoverflow.com/a/55007838/1304161
+    """
     #    ax.figure.canvas.draw() # need to draw before the transforms are set.
     transform = sc.get_transform()
     transOffset = sc.get_offset_transform()
@@ -76,8 +77,6 @@ def get_orig_coords(transform, t_x, t_y):
 
 def get_bboxes(objs, r=None, expand=(1, 1), ax=None, transform=None):
     """
-
-
     Parameters
     ----------
     objs : list, or PathCollection
@@ -464,8 +463,7 @@ def adjust_text(
         save_format="png",
         add_step_numbers=True,
         *args,
-        **kwargs
-):
+        **kwargs):
     """Iteratively adjusts the locations of texts.
 
     Call adjust_text the very last, after all plotting (especially
@@ -581,6 +579,7 @@ def adjust_text(
             t_x, t_y = transform.transform(tupxy)
             x[ix] = t_x
             y[ix] = t_y
+
     orig_xy = [get_text_position(text, ax) for text in texts]
     orig_x = [xy[0] for xy in orig_xy]
     orig_y = [xy[1] for xy in orig_xy]
@@ -598,7 +597,7 @@ def adjust_text(
         precision_x = np.inf
     else:
         precision_x = precision * sum_width
-    #
+
     if not any(list(map(lambda val: "y" in val, only_move.values()))):
         precision_y = np.inf
     else:
@@ -621,21 +620,19 @@ def adjust_text(
         try:
             add_bboxes = get_bboxes(add_objects, r, (1, 1), ax)
         except:
-            raise ValueError(
-                "Can't get bounding boxes from add_objects - is'\
-                             it a flat list of matplotlib objects?"
-            )
-            return
+            raise ValueError("Can't get bounding boxes from add_objects - is it a "
+                             "flat list of matplotlib objects?")
+
         text_from_objects = True
+
     for text in texts:
         text.set_va(va)
         text.set_ha(ha)
+
     if save_steps:
         if add_step_numbers:
             plt.title("Before")
-        plt.savefig(
-            "%s%s.%s" % (save_prefix, "000a", save_format), format=save_format, dpi=150
-        )
+        plt.savefig("%s%s.%s" % (save_prefix, "000a", save_format), format=save_format, dpi=150)
 
     if autoalign:
         if autoalign is True:
@@ -731,7 +728,8 @@ def adjust_text(
         # failure to converge)
         if (qx < precision_x and qy < precision_y) or np.all([qx, qy] >= histm):
             break
-        # Now adding arrows from texts to their original locations if required
+
+    # Now adding arrows from texts to their original locations if required
     if "arrowprops" in kwargs:
         bboxes = get_bboxes(texts, r, (1, 1), ax)
         kwap = kwargs.pop("arrowprops")
@@ -755,7 +753,6 @@ def adjust_text(
             plt.savefig(
                 "%s%s.%s" % (save_prefix, "{0:03}".format(i + 1), save_format),
                 format=save_format,
-                dpi=150,
-            )
+                dpi=150)
 
-    return i + 1
\ No newline at end of file
+    return i+1
